pub enum EventProcessorError {
GraphQueryFailed {
message: String,
},
MissingDependency {
dependency: Vec<String>,
},
IndexWriteFailed {
message: String,
},
SkipIndexing,
InvalidEventLine {
message: String,
},
PubkyClientError {
message: String,
},
}Variants
GraphQueryFailed
Failed to execute query in the graph database
MissingDependency
The event could not be indexed due to missing graph dependencies
IndexWriteFailed
Failed to complete indexing due to a Redis write error
SkipIndexing
The event appear to be unindexed. Verify the event in the retry queue
InvalidEventLine
The event could not be parsed from a line
PubkyClientError
The Pubky client could not resolve the pubky