pub struct Event {
pub uri: String,
pub event_type: EventType,
pub parsed_uri: ParsedUri,
pub files_path: PathBuf,
}Fields
uri: Stringevent_type: EventTypeparsed_uri: ParsedUrifiles_path: PathBufImplementations
Sourceimpl Event
impl Event
pub fn parse_event( line: &str, files_path: PathBuf, ) -> Result<Option<Self>, DynError>
pub async fn handle(self, moderation: &Moderation) -> Result<(), DynError>
Sourcepub async fn handle_put_event(
self,
moderation: &Moderation,
) -> Result<(), DynError>
pub async fn handle_put_event( self, moderation: &Moderation, ) -> Result<(), DynError>
Handles a PUT event by fetching the blob from the homeserver and using the importer to convert it to a PubkyAppObject.
pub async fn handle_del_event(self) -> Result<(), DynError>