pub struct NexusWatcher {}Implementations
Sourceimpl NexusWatcher
impl NexusWatcher
Sourcepub fn builder() -> NexusWatcherBuilder
pub fn builder() -> NexusWatcherBuilder
Creates a new instance with default configuration
Sourcepub async fn start_from_path(config_dir: PathBuf) -> Result<(), DynError>
pub async fn start_from_path(config_dir: PathBuf) -> Result<(), DynError>
Loads the configuration from a file and starts the Watcher
Sourcepub async fn start_from_daemon(config_dir: PathBuf) -> Result<(), DynError>
pub async fn start_from_daemon(config_dir: PathBuf) -> Result<(), DynError>
Loads the configuration from nexusd service and starts the Watcher
pub async fn start(config: WatcherConfig) -> Result<(), DynError>